# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import winrt.system
from winrt import _winrt_windows_media_capture_core

__all__ = [
    "VariablePhotoCapturedEventArgs",
    "VariablePhotoSequenceCapture",
]

VariablePhotoCapturedEventArgs = _winrt_windows_media_capture_core.VariablePhotoCapturedEventArgs
VariablePhotoSequenceCapture = _winrt_windows_media_capture_core.VariablePhotoSequenceCapture



# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation
import winrt.windows.media.capture

Self = typing.TypeVar('Self')

@typing.final
class VariablePhotoCapturedEventArgs(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> VariablePhotoCapturedEventArgs: ...
    @_property
    def capture_time_offset(self) -> datetime.timedelta: ...
    @_property
    def captured_frame_control_values(self) -> typing.Optional[winrt.windows.media.capture.CapturedFrameControlValues]: ...
    @_property
    def frame(self) -> typing.Optional[winrt.windows.media.capture.CapturedFrame]: ...
    @_property
    def used_frame_controller_index(self) -> typing.Optional[typing.Optional[winrt.system.UInt32]]: ...

@typing.final
class VariablePhotoSequenceCapture(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> VariablePhotoSequenceCapture: ...
    def finish_async(self) -> winrt.windows.foundation.IAsyncAction: ...
    def start_async(self) -> winrt.windows.foundation.IAsyncAction: ...
    def stop_async(self) -> winrt.windows.foundation.IAsyncAction: ...
    def update_settings_async(self) -> winrt.windows.foundation.IAsyncAction: ...
    def add_photo_captured(self, handler: winrt.windows.foundation.TypedEventHandler[VariablePhotoSequenceCapture, VariablePhotoCapturedEventArgs], /) -> winrt.windows.foundation.EventRegistrationToken: ...
    def remove_photo_captured(self, token: winrt.windows.foundation.EventRegistrationToken, /) -> None: ...
    def add_stopped(self, handler: winrt.windows.foundation.TypedEventHandler[VariablePhotoSequenceCapture, winrt.system.Object], /) -> winrt.windows.foundation.EventRegistrationToken: ...
    def remove_stopped(self, token: winrt.windows.foundation.EventRegistrationToken, /) -> None: ...

